@@ -15,13 +15,17 @@ function(...) {
 }
 
 warnonce <- 
-function(id, ...) {
-	if(!isTRUE(get0(flag <- paste0("warned.", as.character(id)[1L]), .MuMInEnv,
-					ifnotfound = FALSE))) {
-		assign(flag, TRUE, envir = .MuMInEnv)
+function(..., show.instance = 0L) {
+	id <- make.names(deparse1(match.call(expand.dots = FALSE)$...))
+	count <- get0(flag <- paste0("warned.", as.character(id)[1L]), .MuMInEnv,
+					ifnotfound = 0L)
+	if(count <= show.instance)
+		assign(flag, count + 1L, envir = .MuMInEnv)
+	if(count == show.instance) {
 		cl <- match.call()
-		cl$id <- NULL
+		cl$show.instance <- NULL
 		cl[[1L]] <- as.name("warning")
+		print(cl)
 		eval.parent(cl)
 	}
 }
@@ -225,8 +229,8 @@ function(x) all(vapply(x[-1L], identical, logical(1L), x[[1L]]))
 }
 
 
-## from stats:::format.perc
-`format.perc` <-
+## from stats:::format_perc
+`format_perc` <-
 function (probs, digits) 
 paste(format(100 * probs, trim = TRUE, scientific = FALSE, digits = digits), 
     "%")
